Enum Nextkl
#[repr(u8)]pub enum Nextkl {
Plus0 = 0,
Plus1 = 1,
_RESERVED_2 = 2,
_RESERVED_3 = 3,
}Variants
Plus0 = 0
OBKINDEX represents the index of the option byte key stored for the hide protection level indicated in SBS_HDPLSR.
Plus1 = 1
OBKINDEX represents the index of the option byte key stored for the hide protection level indicated in SBS_HDPLSR plus one (e.g. if HDPL=1 in SBS_HDPLR the key of level 2 is selected).
_RESERVED_2 = 2
_RESERVED_3 = 3
Implementations